package com.chinaitop.agile.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.feign.service.KeepaccountFeignService;
import com.chinaitop.agile.model.DataKcglFcbgzDefault;
import com.chinaitop.agile.model.DataKcglFcbgzDefaultExample;
import com.chinaitop.agile.service.DataKcglFcbgzDefaultService;
import com.chinaitop.agile.service.KeepAccountService;
import com.chinaitop.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/keepAccount")
@Api(value= "KeepAccountController", description = "保管账控制类")
public class KeepAccountController {
	
	@Resource
	private KeepAccountService keepAccountService;
	@Resource
	private DataKcglFcbgzDefaultService fcbgzService;
	@Resource
	private KeepaccountFeignService keepaccountFeignService;

	/**
	 * 保管明细账列表
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @param ch 仓号ID
	 * @param hwh 货位号ID
	 * @param lspz 品种
	 * @param lsxz 货物性质
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/list", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="保管明细账列表", notes = "保管明细账列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "ch", value = "仓号ID", paramType = "query"),
        @ApiImplicitParam(name="hwh", value="货位号ID", paramType="query"),
		@ApiImplicitParam(name="lspz", value="品种", paramType="query"),
		@ApiImplicitParam(name="lsxz", value="货物性质", paramType="query"),
		@ApiImplicitParam(name="startDate", value="开始时间", paramType="query"),
		@ApiImplicitParam(name="endDate", value="结束时间", paramType="query")
	})
	public PageInfo<Map<String, Object>> list(HttpServletRequest request, Integer pageNum, Integer pageSize, 
			Integer ch, Integer hwh, Integer lspz, Integer lsxz, String startDate, String endDate) {
		Map<String, Object> map = new HashMap<String, Object>();
		if (ch != null) {
			map.put("ch", ch);
		}
		if (hwh != null) {
			map.put("hwh", hwh);
		}
		if (lspz != null) {
			map.put("pz", lspz+"");
		}
		if (lsxz != null) {
			map.put("hwxz", lsxz+"");
		}
		if (startDate != null && !"".equals(startDate)) {
			map.put("startDate", startDate+" 00:00:00");
		}
		if (endDate != null && !"".equals(endDate)) {
			map.put("endDate", endDate+" 23:59:59");
		}
		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"),"");
		if (null != orgId && !"".equals(orgId)) {
			map.put("orgId", orgId);
		}
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		List<Map<String, Object>> list = keepAccountService.selectHouseKeepAccountData(map);
		PageInfo<Map<String, Object>> pageInfo = new PageInfo<Map<String, Object>>(list);
		return pageInfo;
	}

	/**
	 * 分仓保管列表，按天统计
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @param ch 仓号ID
	 * @param hwh 货位号ID
	 * @param lspz 品种
	 * @param lsxz 货物性质
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@SuppressWarnings("all")
	@RequestMapping(value="/houseKeepAccountList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="分仓保管列表，按天统计", notes = "分仓保管列表，按天统计，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "ch", value = "仓号ID", paramType = "query"),
        @ApiImplicitParam(name="hwh", value="货位号ID", paramType="query"),
		@ApiImplicitParam(name="lspz", value="品种", paramType="query"),
		@ApiImplicitParam(name="lsxz", value="货物性质", paramType="query"),
		@ApiImplicitParam(name="startDate", value="开始时间", paramType="query"),
		@ApiImplicitParam(name="endDate", value="结束时间", paramType="query")
	})
	public PageInfo<DataKcglFcbgzDefault> houseKeepAccountList(HttpServletRequest request, Integer pageNum, Integer pageSize, 
			Integer ch, Integer hwh, Integer lspz, Integer lsxz, String startDate, String endDate) {

		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"),"");

		DataKcglFcbgzDefaultExample example = new DataKcglFcbgzDefaultExample();
		DataKcglFcbgzDefaultExample.Criteria criteria = example.createCriteria();
		//( srsl > ? and pz = ? and hwxz = ? ) or( zcsl > ? and pz = ? and hwxz = ? )
		DataKcglFcbgzDefaultExample.Criteria criteria1 = example.createCriteria();
		criteria.andSrslGreaterThan(0.0);
		criteria.andDirectionEqualTo(1);
		if (null != orgId) {
			criteria.andUnitidEqualTo(orgId);
		}
		criteria1.andZcslGreaterThan(0.0);
		criteria1.andDirectionEqualTo(1);
		
		if (ch!=null) {
			criteria.andChEqualTo(ch);
			criteria1.andChEqualTo(ch);
		}
		if (hwh!=null) {
			criteria.andHwhEqualTo(hwh);
			criteria1.andHwhEqualTo(hwh);
		}
		if (lspz != null) {
			criteria.andPzEqualTo(lspz+"");
			criteria1.andPzEqualTo(lspz+"");
		}
		if (lsxz != null) {
			criteria.andHwxzEqualTo(lsxz+"");
			criteria1.andHwxzEqualTo(lsxz+"");
		}
		if (startDate != null && !"".equals(startDate)) {
			Date start_rq = ParameterUtil.string2datetime(startDate+" 00:00:00");
			criteria.andRqGreaterThanOrEqualTo(start_rq);
			criteria1.andRqGreaterThanOrEqualTo(start_rq);
		}
		if (endDate != null && !"".equals(endDate)) {
			Date end_rq = ParameterUtil.string2datetime(endDate+" 23:59:59");
			criteria.andRqLessThanOrEqualTo(end_rq);
			criteria1.andRqLessThanOrEqualTo(end_rq);
		}
		if (null != orgId) {
			criteria1.andUnitidEqualTo(orgId);
		}
		example.or(criteria1);
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		example.setOrderByClause("ModifyDate desc");
		List<DataKcglFcbgzDefault> list = keepAccountService.queryTotalByExample(example);
		for (DataKcglFcbgzDefault fcbgz : list) {
			try {
				fcbgz.setUnitid(orgId);
				DataKcglFcbgzDefault obj = fcbgzService.findConditionMax(fcbgz);
				fcbgz.setKcsl(obj.getKcsl());
				//获取是否审核和是否记账
				Map<String, Object> map = keepaccountFeignService.selectHouseKeepAccountData(fcbgz.getCh(), 
						fcbgz.getHwh(), 
						Integer.parseInt(fcbgz.getHwxz()), 
						Integer.parseInt(fcbgz.getPz()),
						ParameterUtil.date2string(fcbgz.getRq()),
						0);
				Map<String, Object> datamap = (Map<String, Object>) map.get("obj");
				String isJZ = ObjectUtils.toString(datamap.get("accountingPerson"),"");
				String isSH = ObjectUtils.toString(datamap.get("auditor"),"");
				if ("".equals(isJZ)) {
					fcbgz.setJZ(true);
				} else {
					fcbgz.setJZ(false);
				}
				if ("".equals(isSH)) {
					fcbgz.setSH(true);
				} else {
					fcbgz.setSH(false);
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		PageInfo<DataKcglFcbgzDefault> pageInfo = new PageInfo<DataKcglFcbgzDefault>(list);
		return pageInfo;
	}

}
