package com.chinaitop.agile.utils;

import com.chinaitop.agile.feign.service.BasicEnumFeignService;
import com.chinaitop.agile.model.DataKcglKcswDefault;
import com.chinaitop.utils.ParameterUtil;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.*;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @auther mafy
 * @createtime 2017/10/26 0026
 * 导入公共类，直接调用importFile方法即可
 */
@Service
public class ImportServiceImpl {

    @Resource
    private BasicEnumFeignService basicEnumFeignService;

    /**
     * 拼写第四行总计
     * @return
     * @throws Exception
     */
    public Map<String, Object> temperData(String pxtjPath, HttpServletRequest request, Map<String,Object> foodStatistics,
                                          List<DataKcglKcswDefault> listNumberTotal, String orgId) throws Exception{
        Map<String, Object> modelMap = new HashMap<String, Object>();
        // 服务器路径
        String rootPath = request.getSession().getServletContext().getRealPath("");
//        String rootPath = "F:\\yunnanDepot\\depot-web-yunnan\\src\\main\\resources\\static\\app\\agile\\service";
        // 文件相对路径
        String relativePath = "/粮食品种统计模板.xlsx";
        //读取临时文件，并且返回错误信息
        String fileAllpath = rootPath+relativePath;
        //创建临时文件
        createTemp(pxtjPath,fileAllpath);
//        String fileAllpath = "E:\\粮食品种统计模板.xlsx";
        //获取File
        File tempFile = new File(fileAllpath);
        //获取第四行数据
        Workbook workbook = getWorkbook(tempFile,fileAllpath);
        //向临时模板写入数据
        setFileName(workbook,foodStatistics,listNumberTotal,orgId);

        // 首先要创建一个原始Excel文件的输出流对象！
        FileOutputStream excelFileOutPutStream = new FileOutputStream(fileAllpath);
        // 将最新的 Excel 文件写入到文件输出流中，更新文件信息！
        workbook.write(excelFileOutPutStream);
        // 执行 flush 操作， 将缓存区内的信息更新到文件上
        excelFileOutPutStream.flush();
        // 使用后，及时关闭这个输出流对象， 好习惯，再强调一遍！
        excelFileOutPutStream.close();
        modelMap.put("fileAllpath",fileAllpath);
        return modelMap;
    }

    /**
     * 创建临时文件
     * @param oldPath 老的文件目录
     * @param newPath 新的文件目录
     * @throws Exception
     */
    public void createTemp(String oldPath, String newPath) throws Exception{
        File oldFile = new File(oldPath);
        File file = new File(newPath);
        FileInputStream in = new FileInputStream(oldFile);
        FileOutputStream out = new FileOutputStream(file);;

        byte[] buffer=new byte[2097152];
        int readByte = 0;
        while((readByte = in.read(buffer)) != -1){
            out.write(buffer, 0, readByte);
        }

        in.close();
        out.close();
    }

    //获取workbook
    private Workbook getWorkbook(File file ,String FileName){
        Workbook wb = null;
        try {
            InputStream is = new FileInputStream(file);
            if(ExcelImportUtils.isExcel2007(FileName)) {
                wb = new XSSFWorkbook(is);
            }
            else {
                wb = new HSSFWorkbook(is);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return wb;
    }

    //向临时模板写入数据
    private void setFileName(Workbook workbook, Map<String,Object> foodStatistics, List<DataKcglKcswDefault> listNumberTotal, String orgId){

        CellStyle cellStyle = workbook.createCellStyle();
        cellStyle.setAlignment(CellStyle.ALIGN_CENTER);
        Sheet sheetX = workbook.getSheetAt(0);
        Row row = sheetX.getRow(3);
        //向第四行空格写数据
        row.createCell(1, Cell.CELL_TYPE_STRING).setCellValue(String.format("%.2f",foodStatistics.get("xm")));
        row.createCell(2, Cell.CELL_TYPE_STRING).setCellValue(String.format("%.2f",foodStatistics.get("dg")));
        row.createCell(3, Cell.CELL_TYPE_STRING).setCellValue(String.format("%.2f",foodStatistics.get("xd")));
        row.createCell(4, Cell.CELL_TYPE_STRING).setCellValue(String.format("%.2f",foodStatistics.get("jd")));
        row.createCell(5, Cell.CELL_TYPE_STRING).setCellValue(String.format("%.2f",foodStatistics.get("ym")));
        row.createCell(6, Cell.CELL_TYPE_STRING).setCellValue(String.format("%.2f",foodStatistics.get("totalNumber")));

        // ------ 创建一行新的数据 ----------//
        // 指定行索引，创建一行数据, 行索引为当前最后一行的行索引 + 1
        int currentLastRowIndex = sheetX.getLastRowNum() + 1;

        //获取仓房名称转换用数据
        Map<String,Object> basicEnumFeign = basicEnumFeignService.getStorehouseList(Integer.parseInt(orgId),"0");
        Map<Integer, Object> storehouseObj = (Map<Integer, Object>) basicEnumFeign.get("houseObj");
        for (DataKcglKcswDefault kcswData:listNumberTotal ) {
            int newRowIndex = currentLastRowIndex ++;
            Row newRow = sheetX.createRow(newRowIndex);

            // 开始创建并设置该行每一单元格的信息，该行单元格的索引从 0 开始
            int cellIndex = 0;

            // 创建一个单元格，设置其内的数据格式为字符串，并填充内容，其余单元格类同
            //仓房名称
            Cell cfmc = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            Map<String,String> houseData = (HashMap<String, String>) storehouseObj.get(kcswData.getCh().toString());
            cfmc.setCellValue(houseData.get("storehouseName"));
            Cell xm = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            //小麦
            if(ParameterUtil.isequal(kcswData.getPz(),"3164")){
                xm.setCellValue(kcswData.getKcsl());
            }else{
                xm.setCellValue("");
            }
            Cell dgxj = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            dgxj.setCellValue("");
            Cell zwxd = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            //中晚籼稻
            if(ParameterUtil.isequal(kcswData.getPz(),"3218") || ParameterUtil.isequal(kcswData.getPz(),"3219")){
                zwxd.setCellValue(kcswData.getKcsl());
            }else{
                zwxd.setCellValue("");
            }
            Cell jd = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            //粳稻
            if(ParameterUtil.isequal(kcswData.getPz(),"3220") || ParameterUtil.isequal(kcswData.getPz(),"3221")){
                jd.setCellValue(kcswData.getKcsl());
            }else{
                jd.setCellValue("");
            }
            Cell ym = newRow.createCell(cellIndex++, Cell.CELL_TYPE_STRING);
            //玉米
            if(ParameterUtil.isequal(kcswData.getPz(),"3165")){
                ym.setCellValue(kcswData.getKcsl());
            }else{
                ym.setCellValue("");
            }
        }
    }
}

